@@ -859,7 +859,13 @@ class JAAQLModel(BaseJAAQLModel):
 
         if KEY__application in inputs:
             application_configs = self.fetch_pivoted_application_schemas()
+            if inputs[KEY__application] not in application_configs:
+                raise HttpStatusException("Application '%s' does not exist!" % inputs[KEY__application])
             app = application_configs[inputs[KEY__application]]
+
+            if inputs[KEY__configuration] not in app:
+                raise HttpStatusException("Configuration '%s' does not exist for application '%s'!" % (inputs[KEY__configuration],
+                                                                                                       inputs[KEY__application]))
             config = app[inputs[KEY__configuration]]
 
             found_db = None
